@@ -11,9 +11,17 @@ from .install import add, remove
 from .listing import get_distribution
 from .system import get_apt_history
 
-__all__ = ["DistributionNotFound", "get_entry_points", "add", "remove",
-           "auto_discover", "discover", "get_repo_files", "get_apt_history",
-           "get_distribution"]
+__all__ = [
+    "DistributionNotFound",
+    "get_entry_points",
+    "add",
+    "remove",
+    "auto_discover",
+    "discover",
+    "get_repo_files",
+    "get_apt_history",
+    "get_distribution",
+]
 
 
 def detail_package(self):
@@ -31,7 +39,6 @@ def detail_package(self):
         yield
 
     def summarize():
-        print("{} packages found: {}".format(len(packages),
-                                             ", ".join(packages)))
+        print("{} packages found: {}".format(len(packages), ", ".join(packages)))
 
     return handle, summarize
