@@ -5,17 +5,19 @@ import os
 
 import sh
 
+from understory import pkg
 from understory import term
 
-from .. import pkg
-
 
 main = term.application("pkg", pkg.__doc__)
 
 
 def complete_distname(prefix, **kwargs):
-    return (dist.project_name for dist in pkg.listing.get_environment()
-            if dist.startswith(prefix))
+    return (
+        dist.project_name
+        for dist in pkg.listing.get_environment()
+        if dist.startswith(prefix)
+    )
 
 
 @main.register()
@@ -23,27 +25,39 @@ class Publish:
     """Publish a release to PyPI and GitHub."""
 
     def setup(self, add_arg):
-        add_arg("rule", choices=["patch", "minor", "major"],
-                help="increment to bump the version")
+        add_arg(
+            "rule",
+            choices=["patch", "minor", "major"],
+            help="increment to bump the version",
+        )
 
     def run(self, stdin, log):
         stashed = False
         try:
             sh.git("diff", "--quiet")
         except sh.ErrorReturnCode_1:
-            if input("Repo is dirty! Stash? [y/N]").lower() == "y":
+            if input("Repo is dirty! Stash? [y/N] ").lower() == "y":
                 sh.git("stash", "push", "--keep-index")
                 stashed = True
             else:
                 return 1
         try:
-            print(sh.poetry("run", "pytest"))
+            print(
+                sh.poetry(
+                    "run",
+                    "pytest",
+                    "--doctest-modules",
+                    '--doctest-glob="README*"',
+                    "--cov=.",
+                )
+            )
         except sh.ErrorReturnCode_5:
             pass
         env = os.environ.copy()
         env.update(NO_COLOR="1", GH_PAGER="cat")
-        private = json.loads(str(sh.gh("repo", "view", "--json",
-                                       "isPrivate", _env=env)))["isPrivate"]
+        private = json.loads(
+            str(sh.gh("repo", "view", "--json", "isPrivate", _env=env))
+        )["isPrivate"]
         print(sh.poetry("version", self.rule))
         print(sh.poetry("build"))
         if not private:
@@ -51,18 +65,24 @@ class Publish:
         version = str(sh.poetry("version", "-s")).strip()
         print(sh.git("commit", "-a", "-m", f"Release {version}"))
         print(sh.git("push"))
-        asset = str(sh.tail(sh.grep(sh.ls("-1tr", "dist"), ".whl"),
-                    "-n1")).strip()
+        asset = str(sh.tail(sh.grep(sh.ls("-1tr", "dist"), ".whl"), "-n1")).strip()
         try:
-            previous_version_string = str(sh.git("describe", "--tags",
-                                                 "--abbrev=0")).strip() + ".."
+            previous_version_string = (
+                str(sh.git("describe", "--tags", "--abbrev=0")).strip() + ".."
+            )
         except sh.ErrorReturnCode_128:
             previous_version_string = ""
-        changelog = sh.git("--no-pager", "log", "--no-color",
-                           f"{previous_version_string}HEAD^", "--oneline",
-                           "--no-decorate")
-        print(sh.gh("release", "create", version, f"dist/{asset}",
-                    "--notes", changelog))
+        changelog = sh.git(
+            "--no-pager",
+            "log",
+            "--no-color",
+            f"{previous_version_string}HEAD^",
+            "--oneline",
+            "--no-decorate",
+        )
+        print(
+            sh.gh("release", "create", version, f"dist/{asset}", "--notes", changelog)
+        )
         print(sh.git("pull"))
         print(f"Published release {version}!")
         if stashed:
@@ -80,17 +100,22 @@ class List:
     """list installed distributions"""
 
     def setup(self, add_arg):
-        add_arg("dists", nargs="*", completer=complete_distname,
-                help="name of distribution(s) to list")
-        add_arg("-d", "--deps", action="store_true",
-                help="include dependencies")
-        add_arg("-v", "--verbosity", action="count", default=0,
-                help="show more details")
+        add_arg(
+            "dists",
+            nargs="*",
+            completer=complete_distname,
+            help="name of distribution(s) to list",
+        )
+        add_arg("-d", "--deps", action="store_true", help="include dependencies")
+        add_arg(
+            "-v", "--verbosity", action="count", default=0, help="show more details"
+        )
 
     def run(self, stdin, log):
         get_dist = pkg.listing.get_distributions
-        for dist in sorted(self.dists if self.dists else
-                           get_dist(dependencies=self.deps)):
+        for dist in sorted(
+            self.dists if self.dists else get_dist(dependencies=self.deps)
+        ):
             self.print_dist(dist)
         return 0
 
@@ -102,8 +127,9 @@ class List:
         if not self.machine:
             print("/c/{}".format(name), end=" ")
 
-        def machined_print(*prefixes, value, color="d,w",
-                           prefix=True, indent="", end="\n"):
+        def machined_print(
+            *prefixes, value, color="d,w", prefix=True, indent="", end="\n"
+        ):
             """
             machinable human output
 
@@ -132,16 +158,24 @@ class List:
                     pass
                 print(indent, end="")
 
-            print(*(["/lg/{}/X/".format(p) for p in prefixes] + value),
-                  sep="/X//lg/:/X/", end=end)
+            print(
+                *(["/lg/{}/X/".format(p) for p in prefixes] + value),
+                sep="/X//lg/:/X/",
+                end=end,
+            )
 
-        machined_print("version", value=version, color="lr,Cle", prefix=None,
-                       end=": " if self.verbosity else "")
+        machined_print(
+            "version",
+            value=version,
+            color="lr,Cle",
+            prefix=None,
+            end=": " if self.verbosity else "",
+        )
 
         if self.verbosity:
             summary = details.pop("summary")
             if summary.lower().startswith(name + " "):
-                summary = summary[len(name):].lstrip(":")
+                summary = summary[len(name) :].lstrip(":")
             summary = summary.strip(". ")
             machined_print("summary", value=summary, prefix=None)
 
@@ -166,42 +200,52 @@ class List:
                     if self.machine:
                         for e_pnt, e_obj in sorted(e_points.items()):
                             o = "{}={}:{}".format(e_pnt, e_obj[0], e_obj[1][0])
-                            machined_print("entrances", e_cls, indent=4,
-                                           color="g", value=o)
+                            machined_print(
+                                "entrances", e_cls, indent=4, color="g", value=o
+                            )
                     else:
                         indent = 6 + len(e_cls)
                         joiner = "\n" + (" " * (indent))
-                        o = joiner.join("/g/{}/X/ /d,lg/{}:{}"
-                                        "/X/".format(ep, eo[0], eo[1][0])
-                                        for ep, eo in sorted(e_points.items()))
-                        machined_print("entrances", e_cls, value=o, indent=4,
-                                       color="g")
+                        o = joiner.join(
+                            "/g/{}/X/ /d,lg/{}:{}" "/X/".format(ep, eo[0], eo[1][0])
+                            for ep, eo in sorted(e_points.items())
+                        )
+                        machined_print("entrances", e_cls, value=o, indent=4, color="g")
 
             location = str(d.location)
             home_dir = str(d.location.home())
             if location.startswith(home_dir):
-                location = "~" + location[len(home_dir):]
+                location = "~" + location[len(home_dir) :]
             if d.is_dirty():
                 location += " /r/*/X/"
             machined_print("installed", indent=2, color="d,b", value=location)
 
         if self.verbosity > 1:
             if details["url"]:
-                machined_print("website", value=details["url"].rstrip("/"),
-                               color="b", indent=2)
+                machined_print(
+                    "website", value=details["url"].rstrip("/"), color="b", indent=2
+                )
             if details["download_url"]:
-                machined_print("download", color="b", indent=2,
-                               value=details["download_url"].rstrip("/"))
+                machined_print(
+                    "download",
+                    color="b",
+                    indent=2,
+                    value=details["download_url"].rstrip("/"),
+                )
 
             raw_license = details.pop("license")
             if raw_license != "UNKNOWN":
                 try:
                     if " and " in raw_license:
-                        license = "/".join(pkg.licensing.get_license(l).abbr
-                                           for l in raw_license.split(" and "))
+                        license = "/".join(
+                            pkg.licensing.get_license(l).abbr
+                            for l in raw_license.split(" and ")
+                        )
                     elif " or " in raw_license:
-                        license = "/".join(pkg.licensing.get_license(l).abbr
-                                           for l in raw_license.split(" or "))
+                        license = "/".join(
+                            pkg.licensing.get_license(l).abbr
+                            for l in raw_license.split(" or ")
+                        )
                     else:
                         license = pkg.licensing.get_license(raw_license).abbr
                 except KeyError:
@@ -235,8 +279,12 @@ class Remove:
     """remove distributions"""
 
     def setup(self, add_arg):
-        add_arg("dist", nargs="+", completer=complete_distname,
-                help="name of distribution(s) to uninstall")
+        add_arg(
+            "dist",
+            nargs="+",
+            completer=complete_distname,
+            help="name of distribution(s) to uninstall",
+        )
 
     def run(self, stdin, log):
         for dist in self.dist:
@@ -247,9 +295,11 @@ class Remove:
 
     def print_tree(self, dist, orphans, indent=0):
         """"""
-        print(" " * indent * 4,
-              "{0.project_name} {0.version} ({0.location})".format(dist),
-              sep="")
+        print(
+            " " * indent * 4,
+            "{0.project_name} {0.version} ({0.location})".format(dist),
+            sep="",
+        )
         for req in pkg.listing._requires(dist):
             if req in orphans:
                 self.print_tree(req, orphans, indent + 1)
