@@ -2,8 +2,9 @@
 Tools for metamodern software development.
 
 Includes support for testing, syntax checking and metrics measurement
-using pytest, flake8, radon respectively. Provides code analysis and
-package/interface introspection.
+using pytest, flake8, radon respectively.
+
+Provides code analysis and package/interface introspection.
 
 """
 
@@ -34,8 +35,7 @@ from . import git
 __all__ = ["git", "get_api", "get_metrics", "rank_cc", "rank_mi"]
 
 
-languages = {"py": "Python", "c": "C",
-             "html": "HTML", "css": "CSS", "js": "Javascript"}
+languages = {"py": "Python", "c": "C", "html": "HTML", "css": "CSS", "js": "Javascript"}
 
 
 def get_metrics(code):
@@ -45,19 +45,32 @@ def get_metrics(code):
     Uses radon to analyze line counts, complexity and maintainability.
 
     """
-    return {"lines": radon.raw.analyze(code),
-            "complexity": radon.complexity.cc_visit(code),
-            "maintainability": radon.metrics.mi_visit(code, True)}
+    return {
+        "lines": radon.raw.analyze(code),
+        "complexity": radon.complexity.cc_visit(code),
+        "maintainability": radon.metrics.mi_visit(code, True),
+    }
 
 
 def test(pkgdir="."):
     """Test pkgdir with pytest and return test results."""
     packages = pkg.discover(pkgdir).pop("packages", [])
-    cmd = ["pytest", "--doctest-modules", "--ignore", "setup.py", "--pep8",
-           "--cov", ",".join(packages), "--cov-report", "xml:coverage.xml",
-           "--junit-xml", "test_results.xml"]
-    proc = subprocess.Popen(cmd, env=os.environ,
-                            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    cmd = [
+        "pytest",
+        "--doctest-modules",
+        "--ignore",
+        "setup.py",
+        "--pep8",
+        "--cov",
+        ",".join(packages),
+        "--cov-report",
+        "xml:coverage.xml",
+        "--junit-xml",
+        "test_results.xml",
+    ]
+    proc = subprocess.Popen(
+        cmd, env=os.environ, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+    )
     _, err = [x.decode("utf-8") for x in proc.communicate()]
     return _parse_junit(), _parse_coverage(), err
 
@@ -65,9 +78,13 @@ def test(pkgdir="."):
 def _parse_junit(path="test_results.xml"):
     suite_tag = xml.etree.ElementTree.parse(str(path)).getroot()
     _suite = dict(suite_tag.attrib)
-    suite = {"tests": _suite["tests"], "errors": _suite["errors"],
-             "failures": _suite["failures"], "skips": _suite["skips"],
-             "cases": collections.defaultdict(collections.OrderedDict)}
+    suite = {
+        "tests": _suite["tests"],
+        "errors": _suite["errors"],
+        "failures": _suite["failures"],
+        "skips": _suite["skips"],
+        "cases": collections.defaultdict(collections.OrderedDict),
+    }
     for case_tag in suite_tag:
         case = dict(case_tag.attrib)
         outcome = {"type": "success"}
@@ -83,8 +100,7 @@ def _parse_junit(path="test_results.xml"):
             elif child.tag == "system-out":
                 outcome["output"] = child.text
         test_identifier = ":".join((case["classname"], case["name"]))
-        details = {"line": case["line"], "time": case["time"],
-                   "outcome": outcome}
+        details = {"line": case["line"], "time": case["time"], "outcome": outcome}
         suite["cases"][case["file"]][test_identifier] = details
     return suite
 
@@ -98,8 +114,10 @@ def _parse_coverage(path="test_coverage.xml"):
             lines = []
             for line in case.getchildren()[1].getchildren():
                 lines.append((line.attrib["number"], line.attrib["hits"]))
-            coverage[root / case.attrib["filename"]] = \
-                (float(case.attrib["line-rate"]) * 100, lines)
+            coverage[root / case.attrib["filename"]] = (
+                float(case.attrib["line-rate"]) * 100,
+                lines,
+            )
     return coverage
 
 
@@ -155,8 +173,7 @@ def get_api(mod, pkg=None) -> dict:
     members = []
     if module:
         members = _get_namespace_members(module)
-    details = {"name": mod, "mod": module,
-               "members": members, "descendants": {}}
+    details = {"name": mod, "mod": module, "members": members, "descendants": {}}
     try:
         mod_location = module.__path__
         for _, _mod, __ in pkgutil.iter_modules(mod_location):
@@ -198,12 +215,25 @@ def _get_namespace_members(mod):  # NOQA FIXME
             continue
         classes.append((name, cls))
     global_mems = []
-    defaults = ("__all__", "__builtins__", "__cached__", "__doc__", "__file__",
-                "__loader__", "__name__", "__package__", "__spec__")
+    defaults = (
+        "__all__",
+        "__builtins__",
+        "__cached__",
+        "__doc__",
+        "__file__",
+        "__loader__",
+        "__name__",
+        "__package__",
+        "__spec__",
+    )
     for global_mem in inspect.getmembers(mod):
-        if (global_mem in modules or global_mem in exceptions or
-           global_mem in functions or global_mem in classes or
-           global_mem[0] in defaults):
+        if (
+            global_mem in modules
+            or global_mem in exceptions
+            or global_mem in functions
+            or global_mem in classes
+            or global_mem[0] in defaults
+        ):
             continue
         global_mems.append(global_mem)
     return modules, global_mems, exceptions, functions, classes
@@ -221,10 +251,12 @@ def get_members(obj, pred, hidden=True):
     """Return a list of object's members."""
     pub = []
     hid = []
-    keywords = {"function": ("def ", "("),
-                "class": ("class ", ":("),
-                "datadescriptor": ("def ", "("),
-                "function_or_datadescriptor": ("def ", "(")}
+    keywords = {
+        "function": ("def ", "("),
+        "class": ("class ", ":("),
+        "datadescriptor": ("def ", "("),
+        "function_or_datadescriptor": ("def ", "("),
+    }
     document_order = []
     for line in get_code(obj).splitlines():
         keyword, delimiter = keywords[pred]
